@@ -46,10 +46,12 @@ rb_file (const char *filename)
 	int i;
 
 	static char *paths[] = {
+#ifdef SHARE_UNINSTALLED_DIR
 		SHARE_UNINSTALLED_DIR "/",
 		SHARE_UNINSTALLED_DIR "/glade/",
 		SHARE_UNINSTALLED_DIR "/art/",
-		SHARE_UNINSTALLED_DIR "/node-views/"
+		SHARE_UNINSTALLED_DIR "/node-views/",
+#endif
 		SHARE_DIR "/",
 		SHARE_DIR "/glade/",
 		SHARE_DIR "/art/",
