@@ -46,7 +46,7 @@
 #include <stdio.h>
 #include <sys/stat.h>
 
-#include "Rhythmbox.h"
+#include <Rhythmbox.h>
 #include "rb-shell.h"
 #include "rb-debug.h"
 #include "rb-dialog.h"
@@ -246,7 +246,7 @@ static void sourcelist_drag_received_cb (RBSourceList *sourcelist,
 static gboolean rb_shell_show_popup_cb (RBSourceList *sourcelist,
 					RBSource *target,
 					RBShell *shell);
-static void tray_deleted_cb (GtkWidget *win, GdkEventAny *event, RBShell *shell);
+static gboolean tray_destroy_cb (GtkWidget *win, GdkEventAny *event, RBShell *shell);
 
 typedef RBSource *(*SourceCreateFunc)(RBShell *, RhythmDB *db, 
 				      BonoboUIComponent *component);
@@ -762,7 +762,7 @@ idle_do_action (struct RBShellAction *data)
 		g_timeout_add (500 + data->tries*200, (GSourceFunc) idle_do_action, data);
 		goto out_unlock;
 	} else
-		g_warning ("No entry %s in db", data->uri);
+		rb_debug ("No entry %s in db", data->uri);
 
 	data->shell->priv->play_queued = FALSE;
 
@@ -843,12 +843,15 @@ rb_shell_corba_handle_file (PortableServer_Servant _servant,
 	if (rb_playlist_can_handle (uri)) {
 		rb_debug ("parsing uri as playlist: %s", uri);
 		uri = rb_playlist_manager_parse_file (shell->priv->playlist_manager, uri);
+		if (!uri)
+			goto out;
 	} else {
 		rb_debug ("async adding uri: %s", uri);
 		rhythmdb_add_uri_async (shell->priv->db, uri);
 	}
 
 	rb_shell_queue_play (shell, uri);
+out:
 	g_object_unref (G_OBJECT (parser));
 }
 
@@ -1276,7 +1279,7 @@ rb_shell_construct (RBShell *shell)
 	}
 
 	rb_debug ("shell: setting up tray icon");
-	tray_deleted_cb (NULL, NULL, shell);
+	tray_destroy_cb (NULL, NULL, shell);
 
 	bonobo_ui_component_add_verb_list_with_data (shell->priv->ui_component,
 						     rb_shell_verbs,
@@ -1352,13 +1355,9 @@ rb_shell_construct (RBShell *shell)
 	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (shell->priv->source_header), FALSE, TRUE, 0);
 	gtk_box_pack_start_defaults (GTK_BOX (vbox), shell->priv->notebook);
 
-	if (gtk_widget_get_default_direction () != GTK_TEXT_DIR_RTL) {
-		gtk_paned_pack1 (GTK_PANED (shell->priv->paned), shell->priv->sourcelist, TRUE, TRUE);
-		gtk_paned_pack2 (GTK_PANED (shell->priv->paned), vbox, TRUE, TRUE);
-	} else {
-		gtk_paned_pack1 (GTK_PANED (shell->priv->paned), vbox, TRUE, TRUE);
-		gtk_paned_pack2 (GTK_PANED (shell->priv->paned), shell->priv->sourcelist, TRUE, TRUE);
-	}
+	gtk_paned_pack1 (GTK_PANED (shell->priv->paned), 
+			 shell->priv->sourcelist, TRUE, TRUE);
+	gtk_paned_pack2 (GTK_PANED (shell->priv->paned), vbox, TRUE, TRUE);
 
 	vbox = gtk_vbox_new (FALSE, 5);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
@@ -1511,7 +1510,9 @@ rb_shell_construct (RBShell *shell)
 
 	/* Stop here if this is the first time. */
 	if (!eel_gconf_get_boolean (CONF_FIRST_TIME)) {
-		RBDruid *druid = rb_druid_new (shell->priv->db);
+		RBDruid *druid;
+		shell->priv->show_db_errors = TRUE;
+		druid = rb_druid_new (shell->priv->db);
 		gtk_widget_hide (GTK_WIDGET (shell->priv->window));
 		rb_druid_show (druid);
 		g_object_unref (G_OBJECT (druid));
@@ -1853,7 +1854,7 @@ rb_shell_set_duration (RBShell *shell, const char *duration)
 {
 	gboolean playing = rb_shell_player_get_playing (shell->priv->player_shell);
 	char *tooltip;
-		
+
 	if (shell->priv->cached_title == NULL) 
 		tooltip = g_strdup (_("Not playing"));
 	else if (!playing) {
@@ -1865,7 +1866,7 @@ rb_shell_set_duration (RBShell *shell, const char *duration)
 		tooltip = g_strdup_printf (_("%s\n%s"),
 					   shell->priv->cached_title, duration);
 	}
-	
+
 	rb_tray_icon_set_tooltip (shell->priv->tray_icon, tooltip);
 	g_free (tooltip);
 }
@@ -2528,9 +2529,11 @@ rb_shell_show_popup_cb (RBSourceList *sourcelist,
 	return rb_source_show_popup (target);
 }
 
-static void
-tray_deleted_cb (GtkWidget *win, GdkEventAny *event, RBShell *shell)
+static gboolean
+tray_destroy_cb (GtkWidget *win, GdkEventAny *event, RBShell *shell)
 {
+	shell->priv->tray_icon = NULL;
+
 	if (shell->priv->tray_icon) {
 		rb_debug ("caught delete_event for tray icon");
 		gtk_object_sink (GTK_OBJECT (shell->priv->tray_icon));
@@ -2541,8 +2544,12 @@ tray_deleted_cb (GtkWidget *win, GdkEventAny *event, RBShell *shell)
 						   shell->priv->ui_component,
 						   shell->priv->db,
 						   GTK_WINDOW (shell->priv->window));
-	g_signal_connect_object (G_OBJECT (shell->priv->tray_icon), "delete_event",
-				 G_CALLBACK (tray_deleted_cb), shell, 0);
+ 	g_signal_connect_object (G_OBJECT (shell->priv->tray_icon), "destroy-event",
+				 G_CALLBACK (tray_destroy_cb), shell, 0);
+ 
+ 	gtk_widget_show_all (GTK_WIDGET (shell->priv->tray_icon));
+ 
+ 	return TRUE;
 }
 
 static void 
