@@ -857,8 +857,6 @@ rb_playlist_source_save_to_xml (RBPlaylistSource *source, xmlNodePtr parent_node
 	char *internal_name;
 	GtkTreeIter iter;
 
-	rb_thread_helpers_lock_gdk ();
-	
 	node = xmlNewChild (parent_node, NULL, "playlist", NULL);
 	g_object_get (G_OBJECT (source), "name", &name,
 		      "internal-name", &internal_name, NULL);
@@ -869,7 +867,7 @@ rb_playlist_source_save_to_xml (RBPlaylistSource *source, xmlNodePtr parent_node
 	if (!source->priv->automatic) {
 		if (!gtk_tree_model_get_iter_first (GTK_TREE_MODEL (source->priv->model),
 						    &iter))
-			goto out;
+			return;
 		do { 
 			xmlNodePtr child_node = xmlNewChild (node, NULL, "location", NULL);
 			RhythmDBEntry *entry;
@@ -907,7 +905,4 @@ rb_playlist_source_save_to_xml (RBPlaylistSource *source, xmlNodePtr parent_node
 		g_free (limit_str);
 		rhythmdb_query_serialize (source->priv->db, query, node);
 	}
-
-out:
-	rb_thread_helpers_unlock_gdk ();
 }
