@@ -66,6 +66,8 @@ typedef struct
 
 	const char *	(*impl_get_browser_key)	(RBSource *source);
 
+	const char *	(*impl_get_search_key)	(RBSource *source);
+
 	RBEntryView *	(*impl_get_entry_view)	(RBSource *source);
 	GList *		(*impl_get_extra_views)	(RBSource *source);
 
@@ -120,6 +122,8 @@ const char *	rb_source_get_status		(RBSource *source);
 
 const char *	rb_source_get_browser_key	(RBSource *source);
 
+const char *	rb_source_get_search_key	(RBSource *source);
+
 RBEntryView *	rb_source_get_entry_view	(RBSource *source);
 
 GList *		rb_source_get_extra_views	(RBSource *source);
